FmIntTextField class

Inheritance
Implemented types

Constructors

FmIntTextField({bool required = false, int? value, int? defaultValue, String? validator(int? value)?, dynamic map(int value)?})

Properties

defaultValue int?
finalinherited
error String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
required bool
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
no setteroverride
textController TextEditingController
final
value int?
no setterinherited

Methods

addListener(VoidCallback cb) → void
inherited
change(int? value) → void
override
dispose() FutureOr<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited